@@ -4,7 +4,7 @@ module Minitest
   class BinstubReporter < SprintReporter
     def print_list
       results.each do |result|
-        puts "  minitest -n #{result.class}##{result.name}"
+        puts "  minitest -n #{result.class_name}##{result.name}"
       end
     end
   end
